@@ -3,7 +3,10 @@ from .model_loader import (
     unload_model,
 )
 
-from .models_db import get_model_info_from_db
+from .models_db import (
+    get_model_info_from_db,
+    get_models_db,
+)
 
 from .model_downloader import (
     download_model,
